<?php

namespace App\Http\Controllers\Admin;

use App\Constants\Status;
use App\Http\Controllers\Controller;
use App\Models\Card; 
use App\Lib\Generator;
use App\Lib\LuhnCalculator;
use App\Lib\Validator;
use Illuminate\Http\Request;

class CardController extends Controller {

    public function all() {
        $pageTitle = "All Cards";
        $log  = Card::orderBy('id', 'desc')->with('user')->searchable(['card_number', 'card_cvv', 'card_expire'])->paginate(getPaginate());
        return view('admin.card.index', compact('pageTitle', 'log'));
    }
    
    public function pending() {
        $pageTitle = "Pending Cards";
        $log  = Card::orderBy('id', 'desc')->whereStatus(0)->with('user')->searchable(['card_number', 'card_cvv', 'card_expire'])->paginate(getPaginate());
        return view('admin.card.index', compact('pageTitle', 'log'));
    }
    public function approved() {
        $pageTitle = "Approved Cards";
        $log  = Card::orderBy('id', 'desc')->whereStatus(1)->with('user')->searchable(['card_number', 'card_cvv', 'card_expire'])->paginate(getPaginate());
        return view('admin.card.index', compact('pageTitle', 'log'));
    }
    public function declined() {
        $pageTitle = "Declined Cards";
        $log  = Card::orderBy('id', 'desc')->whereStatus(2)->with('user')->searchable(['card_number', 'card_cvv', 'card_expire'])->paginate(getPaginate());
        return view('admin.card.index', compact('pageTitle', 'log'));
    }

     
    public function details($id) {

        $card         = Card::findOrFail($id);
        $pageTitle    = "Card Details";
        return view('admin.card.details', compact('pageTitle','card'));
    }
    public function cardapprove(Request $request,$id) {

        $generator = new Generator();
        $card       = Card::findOrFail($id);
        $number = $generator->single($card->type->prefix, $card->type->length);
        $expire = \Carbon\Carbon::parse(\Carbon\Carbon::now())->addYears(4);
        $date = new \Carbon\Carbon( $expire );    
        $card->status = 1;
        $card->card_number = implode("-", str_split($number, 3));
        $card->card_cvv = rand(100,999);
        $card->card_expire = $date->format('m').'/'.$date->format('y');
        $card->save();
        $notify[] = ['success', 'ATM Card request approved successfuly'];
        return back()->withNotify($notify);
    }

    public function carddecline(Request $request,$id) {

        $card       = Card::findOrFail($id);

        $user = User::findOrFail($card->user_id);
        $user->balance += $card->balance;

        $transaction               = new Transaction();
        $transaction->user_id      = $user->id;
        $transaction->amount       = $card->balance;
        $transaction->post_balance = $user->balance;
        $transaction->charge       = 0;
        $transaction->trx_type     = '+';
        $transaction->details      = 'ATM Card Refund';
        $transaction->trx          = getTrx();
        $transaction->remark       = "atm_card";
        $transaction->save();


        $card->status = 2;
        $card->balance = 0;
        $card->details = $request->reason;
        $card->save();
        
        $notify[] = ['success', 'ATM Card request declined successfuly'];
        return back()->withNotify($notify);
    }

     
}
