<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Lib\OTPManager;
use App\Models\PasswordReset;
use App\Models\User;
use App\Models\OtpVerification;
use Illuminate\Http\Request;

class OTPController extends Controller {

    public function codeVerify(Request $request)
    { 
        $request->validate([
            'code'  => 'required',
            'email' => 'required',
        ]);
        
        $code = str_replace(' ', '', $request->code);
        //return intval(auth()->user()->access_pin);
        //return PasswordReset::where('token', $code)->where('email', $request->email)->count();
        $user = auth()->user();
        if($user->access_type == 1)
        { 
            if (PasswordReset::where('token', $code)->where('email', $request->email)->count() != 1) 
            {
                $notify[] = ['error', 'Invalid Login OTP Detected'];
                return back()->withNotify($notify);
            }
        }
        
        else
        { 
            if (intval(auth()->user()->access_pin)  !== intval($code)) 
            {
                $notify[] = ['error', 'Invalid Login OTP Detected'];
                return back()->withNotify($notify);
            }
        }


        session(['logged_in_session' => auth()->user()->username]);
        $notify[] = ['success', 'Login Successful'];
        $user                     = auth()->user();
        
        return to_route('user.home')->withNotify($notify);
    }

    protected function checkCodeValidity($session, $addMin = 2) {
        if($session)
        {

        if (!$session->created_at) {
            return false;
        }
        if (\Carbon\Carbon::parse($session->created_at)->addMinutes($addMin) < \Carbon\Carbon::now()) {
            return false;
        }

        }
        return true;
    }

    public function sendOtpCodeEmail(Request $request)
    {
        $user                     = auth()->user();
        $session = PasswordReset::where('email', $user->email)->first();
        // return \Carbon\Carbon::parse($session->created_at);

        if($session){

        if ($this->checkCodeValidity($session)) {
            $targetTime = \Carbon\Carbon::parse($session->created_at)->addMinutes(2)->timestamp;
            $delay = $targetTime - time();

            $notify[] = ['error', 'Please try after ' . $delay . ' seconds'];
            return back()->withNotify($notify);
        }

        }

        PasswordReset::where('email', $user->email)->delete();
        $code                 = verificationCode(6);
        $password             = new PasswordReset();
        $password->email      = $user->email;
        $password->token      = $code;
        $password->created_at = \Carbon\Carbon::now();
        $password->save();

        $userIpInfo      = getIpInfo();
        $userBrowserInfo = osBrowser();
        notify($user, 'LOGIN_OTP', [
            'code'             => $code,
            'operating_system' => @$userBrowserInfo['os_platform'],
            'browser'          => @$userBrowserInfo['browser'],
            'ip'               => @$userIpInfo['ip'],
            'time'             => @$userIpInfo['time'],
        ], ['email'], false);

        $email = $user->email;
        session()->put('pass_res_mail', $email);
        $notify[] = ['success', 'Login OTP reset email sent successfully'];
        return back()->withNotify($notify);
    }


    public function verifyOtp() {
        $pageTitle    = 'OTP Verification';
        $verification = OtpVerification::findOrFail(sessionVerificationId());

        if ($verification->used_at) {
            return to_route('user.home');
        }

        return view($this->activeTemplate . 'user.otp.verify', compact('pageTitle', 'verification'));
    }

    public function submitOTP(Request $request, $id = 0) {
        $request->validate(['otp' => 'required|digits:6']);

        $verification = OtpVerification::find($id);

        $otpManager               = new OTPManager();
        $otpManager->verification = $verification;
        $otpManager->checkOTP($request->otp);

        $verification->used_at = now();

        if ($verification->send_via == '2fa') {
            $verification->otp        = $request->otp;
            $verification->expired_at = now();
        }

        $verification->save();
        return to_route($verification->additional_data->after_verified);
    }

    public function resendOtp($id) {
        $verification = OtpVerification::find($id);

        if (!$verification) {
            return to_route('user.home');
        }

        if ($verification->user_id != auth()->id()) {
            abort(403, 'Unauthorized Action');
        }

        $otpManager               = new OTPManager();
        $otpManager->verification = $verification;
        $otpManager->renewOTP();

        return to_route('user.otp.verify');
    }
}
