@extends('admin.layouts.app')
@section('panel')
    <div class="row gy-4">
        <div class="col-xl-4 mb-30">
            <div class="card b-radius--10 overflow-hidden box--shadow1">

                <div class="card-body">
                    <ul class="list-group list-group-flush">
                        <li class="list-group-item">
                            <span class="fw-bold">@lang('Account No.')</span>
                            @can('admin.users.detail')
                                <a class="fw-bold" href="{{ route('admin.users.detail', $card->user_id) }}">{{ @$card->user->fullname }}</a>
                            @else
                                {{ @$card->user->account_number }}
                            @endcan
                        </li>

                        <li class="list-group-item">
                            <span class="fw-bold">@lang('Type')</span>
                            <span>{{ __(@$card->type->name) }}</span>
                        </li>

                        <li class="list-group-item">
                            <span class="fw-bold">@lang('Date of Application')</span>
                            <span>{{ showDateTime($card->created_at, 'd M, Y, h:i A') }}</span>
                        </li>

                        <li class="list-group-item">
                            <span class="fw-bold">@lang('Card Number')</span>
                            <span>{{ $card->card_number }}</span>
                        </li>
                        <li class="list-group-item">
                            <span class="fw-bold">@lang('Card CVV')</span>
                            <span>{{ $card->card_cvv }}</span>
                        </li>
                        <li class="list-group-item">
                            <span class="fw-bold">@lang('Card Expiry')</span>
                            <span>{{ $card->card_expire}}</span>
                        </li>

                        <li class="list-group-item">
                            <span class="fw-bold">@lang('Balance') </span>
                            <span class="fw-bold text--warning">{{ showAmount($card->balance) }} {{ __($card->currency) }}</span>
                        </li>

                        

                        <li class="list-group-item">
                            <span class="fw-bold">@lang('Status')</span>
                            @php echo $card->status_badge; @endphp
                        </li>
                    </ul> 
                </div>
            </div>
        </div>

        <div class="col-xl-8 mb-30">

            <div class="card b-radius--10 overflow-hidden box--shadow1">
                <div class="card-body">
                    
                    @if ($card->status == 0)
                        <div class="row mt-4">
                            <div class="col-md-12">
                                @can('admin.card.approve',$card->id)
                                    <button class="btn btn-outline--success confirmationBtn" data-action="{{ route('admin.card.approve', $card->id) }}" data-question="@lang('Are you sure to approve this request?')">
                                        <i class="fas la-check"></i> @lang('Approve')
                                    </button>
                                @endcan

                                @can('admin.card.decline',$card->id)
                                    <button class="btn btn-outline--danger ms-1 rejectBtn" data-action="{{ route('admin.card.decline', $card->id) }}">
                                        <i class="fas fa-ban"></i> @lang('Reject')
                                    </button>
                                @endcan
                            </div>
                        </div>
                    @endif
                </div>
            </div>
        </div>
    </div>

        <x-confirmation-modal />

    <div id="rejectModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Confirmation Alert')</h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="" method="POST">
                    @csrf
                    <div class="modal-body">
                        <div class="form-group">
                            <label>@lang('Reason of Rejection')</label>
                            <textarea name="reason" maxlength="255" class="form-control" rows="5" required>{{ old('message') }}</textarea>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn--primary w-100 h-45">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('style')
    <style>
        .list-group-item {
            display: flex;
            flex-wrap: wrap;
            justify-content: space-between;
            align-items: center;
        }
    </style>
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";

            $('.rejectBtn').on('click', function() {
                var modal = $('#rejectModal');
                modal.find('form')[0].action = $(this).data('action');
                modal.modal('show');
            });
        })(jQuery);
    </script>
@endpush
