@extends($activeTemplate . 'layouts.master')
@section('content')
    
<div class="tab-pane" id="pills-followers" role="tabpanel" aria-labelledby="pills-followers-tab" tabindex="0">
    <div class="d-sm-flex align-items-center justify-content-between mt-3 mb-4">
      <h3 class="mb-3 mb-sm-0 fw-semibold d-flex align-items-center">@lang('Beneficiaries') <span class="badge text-bg-secondary fs-2 rounded-4 py-1 px-2 ms-2">{{count($beneficiaries)}}</span></h3>
      <button type="button" class="btn btn--sm btn-dark add-btn mb-3"><i class="la la-plus-circle"></i>
        @lang('Add Beneficiary')</button>
    </div>
    <div class="row">
      @forelse ($beneficiaries as $beneficiary)
      <div class=" col-md-6 col-xl-4">
        <div class="card">
          <div class="card-body p-4 d-flex align-items-center gap-3">
            <img src="{{ getImage(getFilePath('userProfile') . '/' . $beneficiary->user->image, null, true) }}" alt="" class="rounded-circle" width="40" height="40">
            <div>
               
              <h5 class="fw-semibold mb-0">{{ $beneficiary->account_name }}</h5>
              <span class="fs-2 d-flex align-items-center"><i class="ti ti-building-bank text-dark fs-3 me-1"></i>{{ $beneficiary->account_number }}</span>
              ({{ $beneficiary->short_name }})
            </div>
            <button class="btn btn-primary py-1 px-2 ms-auto EditBeneficiary" data-resources="{{ $beneficiary }}">@lang('Edit Beneficiary')</button>
          </div>
        </div>
      </div>
      @empty
        <center>{{ __($emptyMessage) }}</center>
      @endforelse
       
    </div>
  </div>


    <div class="card custom--card mb-4 @if (!old('account_number')) d-none @endif" id="addForm">
        <div class="card-header">
            <div class="d-flex justify-content-between align-items-center">
                <h5 class="card-title"><span class="title"></span> @lang(' Beneficiary to') @lang($general->site_name)</h5>
                <button type="button" class="btn btn--sm btn--danger close-form-btn"><i class="la la-times"></i></button>
            </div>
        </div>

        <div class="card-body p-4">
            <form action="{{ route('user.beneficiary.own.add') }}" method="POST">
                @csrf
                <input type="hidden" name="id">
                <div class="form-group">
                    <label class="form-label">@lang('Account Number')</label>
                    <input type="text" name="account_number" value="{{ old('account_number') }}" class="form--control" required>
                    <small class="text--danger error-message"></small>
                </div>

                <div class="form-group">
                    <label class="form-label">@lang('Account Name')</label>
                    <input type="text" name="account_name" value="{{ old('account_name') }}" class="form--control" required>
                    <small class="text--danger error-message"></small>
                </div>

                <div class="form-group">
                    <label class="form-label">@lang('Short Name')</label>
                    <input type="text" name="short_name" value="{{ old('short_name') }}" class="form--control" required>
                </div>

                <button type="submit" class="btn w-100 btn--base">@lang('Submit')</button>
            </form>
        </div>
    </div>
 
    @if ($beneficiaries->hasPages())
        {{ paginateLinks($beneficiaries) }}
    @endif
@endsection

@push('script')
    <script>
        'use strict';
        (function($) {
            const addForm = $('#addForm');
            const editForm = $('#editForm');

            $('.add-btn').on('click', function() {
                $(this).parent().hide();
                addForm.find('.title').text(`@lang('Add')`);
                addForm.removeClass('d-none').hide().fadeIn(500);
            });

            $('.close-form-btn').on('click', function() {
                addForm.find('form').trigger("reset");
                $('.add-btn').parent().show();
                addForm.addClass('d-none');
                $('.add-btn').removeClass('d-none').hide().fadeIn(500);
            });


            addForm.on('focusout', '[name=account_number], [name=account_name]', function() {
                let $this = $(this);
                var type = "add";
                onwBeneficiaryChecking($this, type);

            });

            editForm.on('focusout', '[name=account_number], [name=account_name]', function() {
                let $this = $(this);
                var type = "edit";
                onwBeneficiaryChecking($this, type);

            });

            function onwBeneficiaryChecking($this, type) {
                if ($this.val()) {
                    let route = `{{ route('user.beneficiary.check.account') }}`;
                    let data = {}
                    if (type == 'add') {
                        data.account_name = addForm.find('[name=account_name]').val();
                        data.account_number = addForm.find('[name=account_number]').val();
                    } else {
                        data.account_name = editForm.find('[name=account_name]').val();
                        data.account_number = editForm.find('[name=account_number]').val();
                        data.edit = type;
                    }

                    $.get(route, data, function(response) {
                        if (response.error) {
                            $this.parent('.form-group').find('.error-message').text(response
                                .message);
                        } else {
                            if (type == 'add') {
                                addForm.find('[name=account_number]').val(response.data.account_number);
                                addForm.find('[name=account_name]').val(response.data.account_name);
                                addForm.find('.error-message').empty();
                            } else {
                                editForm.find('[name=account_number]').val(response.data.account_number);
                                editForm.find('[name=account_name]').val(response.data.account_name);
                                editForm.find('.error-message').empty();
                            }

                        }
                    });
                } else {
                    addForm.find('.error-message').empty();
                }
            }

            $('.EditBeneficiary').on('click', function() {
                addForm.removeClass('d-none').hide().fadeIn(500);

                $('.add-btn').addClass('d-none').hide().fadeIn(500);

                let beneficiary = $(this).data('resources');
                addForm.find('[name="account_number"]').val(beneficiary.account_number);
                addForm.find('[name="account_name"]').val(beneficiary.account_name);
                addForm.find('[name="short_name"]').val(beneficiary.short_name);
                addForm.find('[name="id"]').val(beneficiary.id);
                addForm.find('.title').text(`@lang('Update')`);
            });



        })(jQuery)
    </script>
@endpush

