<?php

namespace App\Http\Controllers\User;

use App\Constants\Status;
use App\Http\Controllers\Controller;
use App\Models\CardType;
use App\Models\Card;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Validation\ValidationException;

class CardController extends Controller
{

    public function cards()
    {
        $log = Card::where('user_id', auth()->id())->with('type')->with('user')->paginate(getPaginate());
        $pageTitle     = 'ATM Cards';
        return view($this->activeTemplate . 'user.card.log', compact('pageTitle', 'log'));
    }

    public function requestCard()
    {
        $pageTitle     = 'Request New ATM Card';
        $CardMethod = CardType::whereStatus(1)->get();
        return view($this->activeTemplate . 'user.card.request', compact('pageTitle', 'CardMethod'));

    }

    public function confirmRequest(Request $request)
    {
        $request->validate([
            'amount'      => 'nullable|numeric|gt:0',
            'method_code' => 'required',
        ]);
        $amount = $request->amount;
        $user   = auth()->user(); 
        if($amount > 0)
        {
        $method = CardType::whereStatus(1)->whereId($request->method_code)->firstOrFail();
        $charge      = $method->fixed_charge + ($amount * $method->percent_charge / 100);
        $afterCharge = $amount+$charge;
        $finalAmount = $afterCharge * $method->rate;

        if ($method->min_limit > $request->amount || $method->max_limit < $request->amount) {
            $notify[] = ['error', 'Please follow card funding limit'];
            return back()->withNotify($notify);
        }

        if ($user->balance < $finalAmount) {
            $notify[] = ['error', 'Sorry! You don\'t have sufficient balance to process this request'];
            return back()->withNotify($notify);
        }
        
        $user->balance -= $finalAmount;
        $user->save();

        $transaction               = new Transaction();
        $transaction->user_id      = $user->id;
        $transaction->amount       = $finalAmount;
        $transaction->post_balance = $user->balance;
        $transaction->charge       = $charge;
        $transaction->trx_type     = '-';
        $transaction->details      = 'ATM Card Request';
        $transaction->trx          = getTrx();
        $transaction->remark       = "atm_card";
        $transaction->save();
        }

        $card               = new Card();
        $card->card_id      = $request->method_code;
        $card->user_id      = $user->id;
        $card->balance      = $amount;
        $card->status       = 0;  
        $card->save();
        
        $notify[] = ['success', 'Card request placed successfully'];
        return back()->withNotify($notify);
    }
 
}
