<?php

namespace App\Http\Controllers\User;

use App\Constants\Status;
use App\Http\Controllers\Controller;
use App\Lib\OTPManager;
use App\Models\AdminNotification;
use App\Models\BalanceTransfer;
use App\Models\Beneficiary;
use App\Lib\FileManager;
use App\Lib\FormProcessor;
use App\Models\OtherBank;
use App\Models\OtpVerification;
use App\Models\Transaction;
use Illuminate\Http\Request;
use Illuminate\Validation\ValidationException;

class OtherBankTransferController extends Controller
{

    public function index()
    {
        $pageTitle     = 'Bank Transfer';
        return view($this->activeTemplate . 'user.transfer.local.request', compact('pageTitle'));
    } 

    public function transferRequest(Request $request, $id = null)
    {
        $sender = auth()->user();
        $amount = $request->amount;
       


        if ($sender->balance < $amount) {
            throw ValidationException::withMessages(['error' => 'Sorry! You don\'t have sufficient balance']);
            throw ValidationException::withMessages(['error' => 'Sorry! You don\'t have sufficient balance']);
        }

        $transfer                 = new BalanceTransfer();
        $transfer->user_id        = $sender->id;
        $transfer->trx            = getTrx();
        $transfer->beneficiary_id = 0;
        $transfer->amount         = $amount;
        $transfer->type           = 2;
        $transfer->charge         = 0;
        $transfer->status         = Status::TRANSFER_PENDING;
        $transfer->save();

        $sender->balance -= $amount;
        $sender->save();

        $transaction               = new Transaction();
        $transaction->user_id      = $sender->id;
        $transaction->post_balance = $sender->balance;
        $transaction->amount       = $amount;
        $transaction->charge       = $transfer->charge;
        $transaction->trx          = $transfer->trx;
        $transaction->trx_type     = '-';
        $transaction->remark       = "other_bank_transfer";
        $transaction->details      = 'Account Number: '.$request->acc_no.' Account Name: '.$request->acc_name.' Bank: '.$request->bank_name;
        $transaction->save();

        $adminNotification            = new AdminNotification();
        $adminNotification->user_id   = $sender->id;
        $adminNotification->title     = 'New bank transfer request';
        $adminNotification->click_url = urlPath('admin.transfers.details', $transfer->id);
        $adminNotification->save();
 
 
        //SEND MAIL//
        $user         = auth()->user();
        $config       = gs('mail_config');
        $receiverName = $user->fullname;
        $subject      = 'Local Transfer Successful';
        $message      = 'You have successfully transferered the sum of '.$request->amount. 'USD to '.$transaction->details.'. Thank you for banking with us';

        if (gs('en')) {
            $user = [
                'username' => $user->email,
                'email'    => $user->email,
                'fullname' => $receiverName,
            ];
            notify($user, 'DEFAULT', [
                'subject' => $subject,
                'message' => $message,
            ], ['email'], false);
        } 
        //SEND MAIL ENDS


        $notify[] = ['success', "Bank Transfer submitted successfully"];
        return back()->withNotify($notify)->withInput();

    }

     
}
