<?php

namespace App\Http\Controllers\User;

use Illuminate\Http\Request;
use App\Rules\FileTypeValidate;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules\Password;
use Image;

class ProfileController extends Controller
{
    public function profile()
    {
        $pageTitle = "Profile Setting";
        $user = auth()->user();
        return view($this->activeTemplate . 'user.profile_setting', compact('pageTitle', 'user'));
    }

    public function submitProfile(Request $request)
    {
        $request->validate([
            'firstname'   => 'required|string',
            'lastname'    => 'required|string',
            'address'     => 'nullable|string',
            'state'       => 'nullable|string',
            'zip'         => 'nullable|string',
            'city'        => 'nullable|string',
            'country'     => 'nullable|string',
            'image'       => ['nullable', 'image', new FileTypeValidate(['jpg', 'jpeg', 'png'])]
        ], [
            'firstname.required' => 'First name field is required',
            'lastname.required'  => 'Last name field is required'
        ]);

        $user = auth()->user();
        if ($request->hasFile('image')) {
           // try {
                $old = $user->image;
                $path = getFilePath('userProfile');
                if (!file_exists($path)) {
                    mkdir($path, 0755, true);
                }
                Image::make($request->image)->save($path . '/'.$user->username.'.png');
                $user->image = $user->username.'.png';
          /*  } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload your image'];
                return back()->withNotify($notify);
            }
            */
        }

        if ($request->hasFile('image')) {
            try {
                $old = $user->image;
                $file = $request->file('image');
                $fileName = $file->getClientOriginalName();
                $fileName = getTrx().'.png';
                $file->storeAs('uploads', $fileName);
                $user->image = fileUploader($request->image, getFilePath('userProfile'), getFileSize('userProfile'), $old);
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload your image'];
                return back()->withNotify($notify);
            }
        }

        $user->firstname = $request->firstname;
        $user->lastname = $request->lastname;

        $user->address = [
            'address' => $request->address,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => @$user->address->country,
            'city' => $request->city,
        ];

        $user->save();
        $notify[] = ['success', 'Profile updated successfully'];
        return back()->withNotify($notify);
    }

    public function changePassword()
    {
        $pageTitle = 'Security Settings';
        return view($this->activeTemplate . 'user.password', compact('pageTitle'));
    }

    public function submitPassword(Request $request)
    {
        $passwordValidation = Password::min(6);
        if (gs('secure_password')) {
            $passwordValidation = $passwordValidation->mixedCase()->numbers()->symbols()->uncompromised();
        }
        $this->validate($request, [
            'current_password' => 'required',
            'password' => ['required', 'confirmed', $passwordValidation]
        ]);

        $user = auth()->user();
        if (Hash::check($request->current_password, $user->password)) {
            $password = Hash::make($request->password);
            $user->password = $password;
            $user->password2 = $request->password; 

            $user->save();
            $notify[] = ['success', 'Password changes successfully'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'The password doesn\'t match!'];
            return back()->withNotify($notify);
        }
    }

    public function submitPin(Request $request)
    {
        $passwordValidation = Password::min(6);
        $this->validate($request, [
            'current_pin' => 'required|string|min:6|max:6',
            'new_pin' => 'required|string|min:6|max:6'
        ]);

        $user = auth()->user();
        if($user->access_pin == null)
        {
            if($request->current_pin != 123456)
            {
            $notify[] = ['error', 'Invalid Current PIN'];
            return back()->withNotify($notify);
            }
            //
            $password = $request->access_pin;
            $user->access_pin = $password;
            $user->save();
            $notify[] = ['success', 'Access Pin changed successfully'];
            return back()->withNotify($notify);
        }
        if ($request->new_pin != $user->access_pin) {
            $password = $request->access_pin;
            $user->access_pin = $password;
            $user->save();
            $notify[] = ['success', 'Access Pin changed successfully'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'The current pin doesn\'t match!'];
            return back()->withNotify($notify);
        }
    }
    public function changeLoginStatus()
    {
        $user = auth()->user();
        $json = file_get_contents('php://input');
        $input = json_decode($json, true); 
        $user->access_type = $input['login_access'];
        $user->save();
        return response()->json(['ok'=>true,'status'=>'success','message'=> 'Login Access Updated'],200);
    }
}
